%define anolis_release 1
%global _hardened_build 1

%bcond_without pcre

Name: nmap
Epoch: 3
Version: 7.94
Release: %{anolis_release}%{?dist}
Summary: Network exploration tool and security scanner
URL: http://nmap.org/
# Uses combination of licenses based on GPL license, but with extra modification
License: Nmap
Source0: http://nmap.org/dist/%{name}-%{version}.tar.bz2

BuildRequires: automake make
BuildRequires: autoconf
BuildRequires: gcc-c++
BuildRequires: gettext-devel
BuildRequires: libpcap-devel
BuildRequires: libssh2-devel
BuildRequires: libtool
BuildRequires: lua-devel
BuildRequires: openssl-devel
%if %{with_pcre}
BuildRequires: pcre-devel
%endif
BuildRequires: zlib-devel
BuildRequires: gnupg2
Requires: %{name}-ncat = %{EVR}

%define pixmap_srcdir zenmap/share/pixmaps

%description
Nmap is a utility for network exploration or security auditing.  It supports
ping scanning (determine which hosts are up), many port scanning techniques
(determine what services the hosts are offering), and TCP/IP fingerprinting
(remote host operating system identification). Nmap also offers flexible target
and port specification, decoy scanning, determination of TCP sequence
predictability characteristics, reverse-identd scanning, and more. In addition
to the classic command-line nmap executable, the Nmap suite includes a flexible
data transfer, redirection, and debugging tool (netcat utility ncat), a utility
for comparing scan results (ndiff), and a packet generation and response
analysis tool (nping). 

%package ncat
Summary: Nmap's Netcat replacement
Requires(post): %{_sbindir}/alternatives
Requires(preun): %{_sbindir}/alternatives
Obsoletes: nc < 1.109.20120711
Obsoletes: nc6 < 1.00
Provides: nc nc6

%description ncat
Ncat is a feature packed networking utility which will read and
write data across a network from the command line.  It uses both
TCP and UDP for communication and is designed to be a reliable
back-end tool to instantly provide network connectivity to other
applications and users. Ncat will not only work with IPv4 and IPv6
but provides the user with a virtually limitless number of potential
uses.

%package ndiff
Summary: A tool to aid in the comparison of Nmap scans
BuildArch: noarch
Requires: %{name} = %{EVR}
Conflicts: %{name} < 3:7.94

%description ndiff
Ndiff is a tool to aid in the comparison of Nmap scans. Specifically, it
takes two Nmap XML output files and prints the differences between them.
It is capable of showing changes in host states (up or down), port
states (open, closed, etc.), script results, and changes in service and
OS detection.

%package frontend
Summary: A Graphical Front-End for Nmap
Buildarch: noarch
Provides: zenmap = %{EVR}
Requires: %{name} = %{EVR}
Requires: gtk3
Requires: python3-gobject
Conflicts: %{name} < 3:7.94

%description frontend
zenmap is a graphical front-end for the nmap network scanner.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name}-ncat = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

#be sure we're not using tarballed copies of some libraries
#rm -rf liblua libpcap libpcre macosx mswin32 ###TODO###

rm -rf libpcap libpcre macosx mswin32 libssh2 libz

%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
### TODO ## configure  --with-libpcap=/usr ###TODO###
%configure  --with-libpcap=yes --with-liblua=included \
  --with-zenmap --with-ndiff \
  --with-libssh2=yes  \
%if %{without pcre}
  --without-libpcre \
%endif
  --enable-dbus 

%make_build

sed -i 's/-md/-mf/' nping/docs/nping.1

%install
#prevent stripping - replace strip command with 'true'
%make_install STRIP=true

install -m0644 docs/zenmap.1 %{buildroot}%{_mandir}/man1/

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/256x256/apps
install -m0644 zenmap/share/zenmap/pixmaps/zenmap.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/

rm -f %{buildroot}%{_bindir}/uninstall_{zenmap,ndiff}
rm -f %{buildroot}%{_datadir}/ncat/ca-bundle.crt
rmdir %{buildroot}%{_datadir}/ncat

touch %{buildroot}%{_mandir}/man1/nc.1%{_extension}
touch %{buildroot}%{_bindir}/nc

%find_lang nmap --with-man

%post ncat
%{_sbindir}/alternatives --install %{_bindir}/nc nc %{_bindir}/ncat 10 \
  --slave %{_mandir}/man1/nc.1%{_extension} nc.1%{_extension} %{_mandir}/man1/ncat.1%{_extension}

%preun ncat
if [ $1 -eq 0 ]; then
  %{_sbindir}/alternatives --remove nc %{_bindir}/ncat
fi

%files -f nmap.lang
%license LICENSE
%doc docs/README
%doc docs/nmap.usage.txt
%{_bindir}/nmap
%{_bindir}/nping
%{_mandir}/man1/nmap.1%{_extension}
%{_mandir}/man1/nping.1%{_extension}
%{_datadir}/nmap

%files ncat 
%license LICENSE
%ghost %{_bindir}/nc
%{_bindir}/ncat
%ghost %{_mandir}/man1/nc.1%{_extension}
%{_mandir}/man1/ncat.1%{_extension}

%files ndiff
%{_bindir}/ndiff
%{python3_sitelib}/ndiff.py
%{python3_sitelib}/__pycache__/ndiff*
%{_mandir}/man1/ndiff.1*

%files frontend
%{_bindir}/nmapfe
%{_bindir}/xnmap
%{_bindir}/zenmap
%{_datadir}/zenmap
%{python3_sitelib}/radialnet
%{python3_sitelib}/zenmap*
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/zenmap.*
%{_mandir}/man1/zenmap.1*

%files doc
%doc ncat/docs/AUTHORS ncat/docs/README ncat/docs/THANKS ncat/docs/examples

%changelog
* Sun May 21 2023 Funda Wang <fundawang@yeah.net> - 3:7.94-1
- New version 3.94
- Enable ndiff and zenmap as they are python3 compatible
- Add switch on pcre v1

* Sun Jan 15 2023 Funda Wang <fundawang@yeah.net> - 3:7.93-2
- Use man page extesion macro defined in new system-rpm-config

* Tue Sep 20 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3:7.93-1
- update to 7.93

* Fri Apr 15 2022 zhang xianting <zhangxianting@uniontech.com> - 3:7.92-1
- Initial build for Anolis V23
